@@ -31,11 +31,14 @@ def serving(func: Callable) -> Callable:
     _module_serving_func[mod] = func.__name__
 
     def _wrapper(*args, **kwargs):
-        func_signature = inspect.signature(func)
-        if len(func_signature.parameters) <= 1:
-            print(args, kwargs)
-            return func(*args)
-        return func(*args, **kwargs)
+        try:
+            func_signature = inspect.signature(func)
+            if len(func_signature.parameters) <= 1:
+                print(args, kwargs)
+                return func(*args)
+            return func(*args, **kwargs)
+        except:
+            return '{"code":-1}'
 
     return _wrapper
 
