@@ -1,6 +1,7 @@
 from random import randint
 import time
 import zmq
+from aicmder.service import CLIENT_PORT, WORKER_PORT
 
 LRU_READY = "\x01"
 
@@ -9,7 +10,7 @@ worker = context.socket(zmq.REQ)
 
 identity = "%04X-%04X" % (randint(0, 0x10000), randint(0,0x10000))
 worker.setsockopt_string(zmq.IDENTITY, identity)
-worker.connect("tcp://localhost:5556")
+worker.connect(f"tcp://localhost:{WORKER_PORT}")
 
 print("I: (%s) worker ready" % identity)
 worker.send_string(LRU_READY)
