@@ -1,4 +1,5 @@
 import zmq
+from aicmder.service import CLIENT_PORT, WORKER_PORT
 
 LRU_READY = "\x01"
 
@@ -6,8 +7,8 @@ context = zmq.Context(1)
 
 frontend = context.socket(zmq.ROUTER) # ROUTER
 backend = context.socket(zmq.DEALER) # DEALER
-frontend.bind("tcp://*:5555") # For clients
-backend.bind("tcp://*:5556")  # For workers
+frontend.bind(f"tcp://*:{CLIENT_PORT}") # For clients
+backend.bind(f"tcp://*:{WORKER_PORT}")  # For workers
 
 zmq.device(zmq.QUEUE, frontend, backend)
 
